OC.L10N.register(
    "core",
    {
    "Please select a file." : "Pilih berkas",
    "File is too big" : "Berkas terlalu besar",
    "The selected file is not an image." : "Berkas yang dipilih bukanlah sebuah gambar.",
    "The selected file cannot be read." : "Berkas yang dipilih tidak bisa dibaca.",
    "Invalid file provided" : "Berkas yang diberikan tidak sah",
    "No image or file provided" : "Tidak ada gambar atau berkas yang disediakan",
    "Unknown filetype" : "Tipe berkas tidak dikenal",
    "Invalid image" : "Gambar tidak sah",
    "An error occurred. Please contact your admin." : "Terjadi kesalahan. Silakan hubungi admin Anda.",
    "No temporary profile picture available, try again" : "Tidak ada gambar profil sementara yang tersedia, coba lagi",
    "No crop data provided" : "Tidak ada data krop tersedia",
    "No valid crop data provided" : "Tidak ada data valid untuk dipangkas",
    "Crop is not square" : "Pangkas ini tidak persegi",
    "Couldn't reset password because the token is invalid" : "Tidak dapat menyetel ulang kata sandi karena token tidak sah",
    "Couldn't reset password because the token is expired" : "Tidak dapat menyetel ulang kata sandi karena token telah kadaluarsa",
    "%s password reset" : "%s kata sandi disetel ulang",
    "Preparing update" : "Mempersiapkan pembaruan",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Gunakan pembaruan di command line karena pembaruan otomatis di nonaktifkan di config.php. ",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Mengecek tabel %s",
    "Turned on maintenance mode" : "Hidupkan mode perawatan",
    "Turned off maintenance mode" : "Matikan mode perawatan",
    "Maintenance mode is kept active" : "Mode Pemeliharaan masih aktif",
    "Updating database schema" : "Memperbarui skema basis data",
    "Updated database" : "Basis data terbaru",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema basis data dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
    "Checked database schema update" : "Pembaruan skema basis data terperiksa",
    "Checking updates of apps" : "Memeriksa pembaruan aplikasi",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Memeriksa apakah skema untuk %s dapat diperbarui (dapat memerlukan waktu yang lama tergantung pada ukuran basis data)",
    "Checked database schema update for apps" : "Pembaruan skema basis data terperiksa untuk aplikasi",
    "Set log level to debug" : "Atur log level ke debug",
    "Reset log level" : "Atur ulang log level",
    "Starting code integrity check" : "Memulai pengecekan integritas kode",
    "Finished code integrity check" : "Pengecekan integritas kode selesai",
    "%s (incompatible)" : "%s (tidak kompatibel)",
    "Following apps have been disabled: %s" : "Aplikasi berikut telah dinonaktifkan: %s",
    "Already up to date" : "Sudah yang terbaru",
    "Very weak password" : "Kata sandi sangat lemah",
    "Weak password" : "Kata sandi lemah",
    "So-so password" : "Kata sandi lumayan",
    "Good password" : "Kata sandi baik",
    "Strong password" : "Kata sandi kuat",
    "Error occurred while checking server setup" : "Kesalahan tidak terduga saat memeriksa setelan server",
    "Non-existing tag #{tag}" : "Tag tidak ada #{tag}",
    "restricted" : "terbatas",
    "invisible" : "tersembunyi",
    "({scope})" : "({scope})",
    "Delete" : "Hapus",
    "Rename" : "Ubah nama",
    "Collaborative tags" : "Tag kolaboratif",
    "No tags found" : "Tag tidak ditemukan",
    "unknown text" : "teks tidak diketahui",
    "Hello world!" : "Halo dunia!",
    "sunny" : "cerah",
    "Hello {name}, the weather is {weather}" : "Halo {name}, saat ini {weather}",
    "Hello {name}" : "Halo {name}",
    "new" : "baru",
    "_download %n file_::_download %n files_" : ["unduh %n berkas"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Pembaruan sedang dalam proses, meninggalkan halaman ini mungkin dapat mengganggu proses di beberapa lingkungan.",
    "Update to {version}" : "Perbarui ke {version}",
    "An error occurred." : "Terjadi kesalahan.",
    "Please reload the page." : "Silakan muat ulang halaman.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Pembaruan gagal. Untuk informasi berikutnya <a href=\"{url}\">cek posting di forum</a> yang mencakup masalah kami.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Pembaruan gagal. Laporkan masalah ini ke <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">komunitas Nextcloud</a>.",
    "Continue to Nextcloud" : "Lanjutkan ke Nextcloud",
    "Searching other places" : "Mencari tempat lainnya",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} hasil pencarian di folder lain"],
    "Server side authentication failed!" : "Otentikasi dari sisi server gagal!",
    "Please contact your administrator." : "Silahkan hubungi administrator anda.",
    "An internal error occurred." : "Terjadi kesalahan internal.",
    "Please try again or contact your administrator." : "Mohon coba lagi atau hubungi administrator Anda.",
    "Username or email" : "Nama pengguna atau email",
    "Password" : "Kata Sandi",
    "Log in" : "Masuk",
    "Logging in …" : "Log masuk...",
    "Reset password" : "Setel ulang kata sandi",
    "Couldn't send reset email. Please contact your administrator." : "Tidak dapat mengirim email setel ulang. Silakan hubungi administrator Anda.",
    "Password can not be changed. Please contact your administrator." : "Kata sandi tidak dapat diubah. Silakan hubungi administrator Anda",
    "New password" : "Kata sandi baru",
    "I know what I'm doing" : "Saya tahu apa yang saya lakukan",
    "Settings" : "Pengaturan",
    "No" : "Tidak",
    "Yes" : "Ya",
    "No files in here" : "Tidak ada berkas disini",
    "Choose" : "Pilih",
    "Copy" : "Salin",
    "Error loading file picker template: {error}" : "Kesalahan saat memuat templat berkas pemilih: {error}",
    "Error loading message template: {error}" : "Kesalahan memuat templat pesan: {error}",
    "read-only" : "hanya-baca",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} berkas konflik"],
    "One file conflict" : "Satu berkas konflik",
    "New Files" : "Berkas Baru",
    "Already existing files" : "Berkas sudah ada",
    "Which files do you want to keep?" : "Berkas mana yang ingin anda pertahankan?",
    "If you select both versions, the copied file will have a number added to its name." : "Jika anda memilih kedua versi, berkas yang disalin akan memiliki nomor yang ditambahkan sesuai namanya.",
    "Cancel" : "Batal",
    "Continue" : "Lanjutkan",
    "(all selected)" : "(semua terpilih)",
    "({count} selected)" : "({count} terpilih)",
    "Error loading file exists template" : "Kesalahan memuat templat berkas yang sudah ada",
    "Pending" : "Terutnda",
    "Saving..." : "Menyimpan...",
    "Authentication required" : "Diperlukan otentikasi",
    "This action requires you to confirm your password" : "Aksi ini membutuhkan konfirmasi kata sandi Anda",
    "Confirm" : "Konfirmasi",
    "Failed to authenticate, try again" : "Gagal mengotentikasi, coba lagi",
    "seconds ago" : "beberapa detik yang lalu",
    "Connection to server lost" : "Koneksi ke server gagal",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Tidak dapat memuat laman, muat ulang dalam %n detik"],
    "Personal" : "Pribadi",
    "Users" : "Pengguna",
    "Apps" : "Aplikasi",
    "Admin" : "Admin",
    "Help" : "Bantuan",
    "Access forbidden" : "Akses ditolak",
    "File not found" : "Berkas tidak ditemukan",
    "Error" : "Kesalahan",
    "Internal Server Error" : "Kesalahan Server Internal",
    "More details can be found in the server log." : "Rincian lebih lengkap dapat ditemukan di log server.",
    "Technical details" : "Rincian teknis",
    "Remote Address: %s" : "Alamat remote: %s",
    "Request ID: %s" : "ID Permintaan: %s",
    "Type: %s" : "Tipe: %s",
    "Code: %s" : "Kode: %s",
    "Message: %s" : "Pesan: %s",
    "File: %s" : "Berkas: %s",
    "Line: %s" : "Baris: %s",
    "Trace" : "Jejak",
    "Security warning" : "Peringatan keamanan",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Kemungkinan direktori data dan berkas anda dapat diakses dari internet karena berkas .htaccess tidak berfungsi.",
    "Create an <strong>admin account</strong>" : "Buat sebuah <strong>akun admin</strong>",
    "Username" : "Nama pengguna",
    "Storage & database" : "Penyimpanan & Basis data",
    "Data folder" : "Folder data",
    "Configure the database" : "Konfigurasikan basis data",
    "Only %s is available." : "Hanya %s yang tersedia",
    "Install and activate additional PHP modules to choose other database types." : "Pasang dan aktifkan modul PHP tambahan untuk memilih tipe basis data lainnya.",
    "For more details check out the documentation." : "Untuk lebih rinci, periksa pada dokumentasi.",
    "Database user" : "Pengguna basis data",
    "Database password" : "Kata sandi basis data",
    "Database name" : "Nama basis data",
    "Database tablespace" : "Tablespace basis data",
    "Database host" : "Host basis data",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Harap tentukan nomor port beserta nama host (contoh., localhost:5432).",
    "Performance warning" : "Peringatan kinerja",
    "Finish setup" : "Selesaikan instalasi",
    "Finishing …" : "Menyelesaikan ...",
    "Need help?" : "Butuh bantuan?",
    "See the documentation" : "Lihat dokumentasi",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikasi ini memerlukan JavaScript untuk dapat beroperasi dengan benar. Mohon {linkstart}aktifkan JavaScript{linkend} dan muat ulang halaman ini.",
    "Search" : "Cari",
    "Confirm your password" : "Konfirmasi kata sandi Anda",
    "Two-factor authentication" : "Otentikasi Two-factor",
    "Use backup code" : "Gunakan kode cadangan",
    "Cancel log in" : "Batalkan masuk log",
    "Error while validating your second factor" : "Galat ketika memvalidasi faktor kedua anda",
    "App update required" : "Diperlukan perbarui aplikasi",
    "These apps will be updated:" : "Aplikasi berikut akan diperbarui:",
    "These incompatible apps will be disabled:" : "Aplikasi yang tidak kompatibel berikut akan dinonaktifkan:",
    "The theme %s has been disabled." : "Tema %s telah dinonaktfkan.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Pastikan bahwa basis data, folder konfig, dan folder data telah dicadangkan sebelum melanjutkan.",
    "Start update" : "Jalankan pembaruan",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Untuk menghindari waktu habis dengan instalasi yang lebih besar, Anda bisa menjalankan perintah berikut dari direktori instalasi Anda:",
    "Detailed logs" : "Log detail",
    "Update needed" : "Pembaruan dibutuhkan",
    "This %s instance is currently in maintenance mode, which may take a while." : "Instansi %s ini sedang dalam modus pemeliharaan, mungkin memerlukan beberapa saat.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Hubungi administrator sistem anda jika pesan ini terus muncul atau muncul tiba-tiba.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Tidak dapat mengirim email karena tidak ada alamat email untuk nama pengguna ini. Silahkan hubungi administrator Anda.",
    "Couldn't send reset email. Please make sure your username is correct." : "Tidak dapat menyetel ulang email. Mohon pastikan nama pengguna Anda benar.",
    "Dismiss" : "Buang",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Sebuah tautan untuk setel ulang kata sandi Anda telah dikirim ke email Anda. Jika Anda tidak menerima dalam jangka waktu yang wajar, periksa folder spam/sampah Anda.<br>Jika tidak ada, tanyakan pada administrator Anda.",
    "Your files are encrypted. There will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Berkas anda terenkripsi. Tidak ada jalan untuk mendapatkan kembali data anda setelah kata sandi disetel ulang.<br />Jika anda tidak yakin, harap hubungi administrator anda sebelum melanjutkannya. <br />Apa anda ingin melanjutkannya?",
    "Shared" : "Dibagikan",
    "Choose a password for the public link" : "Tetapkan kata sandi untuk tautan publik",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
    "Link" : "Tautan",
    "Password protect" : "Lindungi dengan kata sandi",
    "Allow editing" : "Izinkan penyuntingan",
    "Email link to person" : "Emailkan tautan ini ke orang",
    "Send" : "Kirim",
    "Allow upload and editing" : "Izinkan pengunggahan dan penyuntingan",
    "File drop (upload only)" : "Berkas jatuh (hanya unggah)",
    "Set expiration date" : "Atur tanggal kedaluwarsa",
    "Expiration" : "Kedaluwarsa",
    "Expiration date" : "Tanggal kedaluwarsa",
    "Unshare" : "Batalkan berbagi",
    "Share link" : "Bagikan tautan",
    "Could not unshare" : "Tidak dapat membatalkan pembagian",
    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
    "group" : "grup",
    "remote" : "remote",
    "email" : "surel",
    "Error while sharing" : "Kesalahan saat membagikan",
    "Share details could not be loaded for this item." : "Rincian berbagi tidak dapat dimuat untuk item ini.",
    "_At least {count} character is needed for autocompletion_::_At least {count} characters are needed for autocompletion_" : ["Sekurangnya {count} karakter dibutuhkan untuk autocompletion"],
    "This list is maybe truncated - please refine your search term to see more results." : "Daftar ini mungkin terpotong - harap sari kata pencarian anda untuk melihat hasil yang lebih.",
    "No users or groups found for {search}" : "Tidak ada pengguna atau grup ditemukan untuk {search}",
    "No users found for {search}" : "Tidak ada pengguna ditemukan untuk {search}",
    "An error occurred. Please try again" : "Terjadi kesalahan. Silakan coba lagi",
    "Share" : "Bagikan",
    "Error removing share" : "Terjadi kesalahan saat menghapus pembagian",
    "SQLite will be used as database." : "SQLite akan digunakan sebagai basis data.",
    "For larger installations we recommend to choose a different database backend." : "Untuk instalasi yang lebih besar, kami menyarankan untuk memilih backend basis data yang berbeda.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Terutama saat menggunakan klien desktop untuk sinkronisasi berkas, penggunaan SQLite tidak disarankan.",
    "Wrong password." : "Sandi salah.",
    "New Password" : "Kata sandi Baru"
},
"nplurals=1; plural=0;");
